Package: isopleuros
Title: Ternary Plots
Version: 1.4.0
Authors@R: c(
    person("Nicolas", "Frerebeau", , "nicolas.frerebeau@u-bordeaux-montaigne.fr", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5759-4944")),
    person("Brice", "Lebrun", role = "art",
           comment = c(ORCID = "0000-0001-7503-8685", "Logo designer")),
    person("Université Bordeaux Montaigne", role = "fnd",
           comment = c(ROR = "03pbgwk21")),
    person("CNRS", role = "fnd",
           comment = c(ROR = "02feahw73"))
  )
Maintainer: Nicolas Frerebeau <nicolas.frerebeau@u-bordeaux-montaigne.fr>
Description: Ternary plots made simple. This package allows to create
    ternary plots using 'graphics'. It provides functions to display the
    data in the ternary space, to add or tune graphical elements and to
    display statistical summaries. It also includes common ternary
    diagrams which are useful for the archaeologist (e.g. soil texture
    charts, ceramic phase diagram).
License: GPL (>= 3)
URL: https://codeberg.org/tesselle/isopleuros,
        https://packages.tesselle.org/isopleuros/
BugReports: https://codeberg.org/tesselle/isopleuros/issues
Depends: R (>= 3.5)
Imports: graphics, grDevices, methods, stats, utils
Suggests: interp, rsvg, svglite, tinysnapshot, tinytest
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
X-schema.org-applicationCategory: Archaeological Science
X-schema.org-isPartOf: https://www.tesselle.org
X-schema.org-keywords: archaeometry, archaeological-science,
        ternary-plot, data-visualization, r-package
Collate: 'AllGenerics.R' 'coordinates.R' 'data.R'
        'isopleuros-internal.R' 'isopleuros-package.R'
        'ternary_arrows.R' 'ternary_axes.R' 'ternary_box.R'
        'ternary_contour.R' 'ternary_crosshairs.R' 'ternary_density.R'
        'ternary_ellipse.R' 'ternary_grid.R' 'ternary_hull.R'
        'ternary_image.R' 'ternary_labels.R' 'ternary_lines.R'
        'ternary_mean.R' 'ternary_pairs.R' 'ternary_pca.R'
        'ternary_plot.R' 'ternary_points.R' 'ternary_polygon.R'
        'ternary_segments.R' 'ternary_text.R' 'ternary_title.R'
        'ternary_window.R' 'triangle_phase.R' 'triangle_soil.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2025-03-04 15:31:43 UTC; nicolas
Author: Nicolas Frerebeau [aut, cre] (<https://orcid.org/0000-0001-5759-4944>),
  Brice Lebrun [art] (<https://orcid.org/0000-0001-7503-8685>, Logo
    designer),
  Université Bordeaux Montaigne [fnd] (03pbgwk21),
  CNRS [fnd] (02feahw73)
Repository: CRAN
Date/Publication: 2025-03-04 16:00:02 UTC
Built: R 4.3.3; ; 2025-03-04 18:10:46 UTC; unix
