# Generated by roxygen2: do not edit by hand

export(ternary_axis)
export(ternary_box)
export(ternary_grid)
export(ternary_title)
export(triangle_phase_cas)
export(triangle_phase_ceramic)
export(triangle_soil_folk)
export(triangle_soil_hypres)
export(triangle_soil_shepard)
export(triangle_soil_usda)
exportMethods(coordinates_cartesian)
exportMethods(coordinates_ternary)
exportMethods(ternary_arrows)
exportMethods(ternary_confidence)
exportMethods(ternary_contour)
exportMethods(ternary_crosshairs)
exportMethods(ternary_density)
exportMethods(ternary_ellipse)
exportMethods(ternary_hull)
exportMethods(ternary_image)
exportMethods(ternary_labels)
exportMethods(ternary_lines)
exportMethods(ternary_mean)
exportMethods(ternary_pairs)
exportMethods(ternary_pca)
exportMethods(ternary_plot)
exportMethods(ternary_points)
exportMethods(ternary_polygon)
exportMethods(ternary_segments)
exportMethods(ternary_text)
exportMethods(ternary_tolerance)
exportMethods(tile_bin)
exportMethods(tile_density)
exportMethods(tile_interpolate)
importFrom(grDevices,as.graphicsAnnot)
importFrom(grDevices,as.raster)
importFrom(grDevices,chull)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,contourLines)
importFrom(grDevices,dev.flush)
importFrom(grDevices,dev.hold)
importFrom(grDevices,hcl.colors)
importFrom(grDevices,xyz.coords)
importFrom(graphics,arrows)
importFrom(graphics,layout)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.default)
importFrom(graphics,plot.new)
importFrom(graphics,plot.window)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rasterImage)
importFrom(graphics,segments)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(methods,.valueClassTest)
importFrom(methods,setGeneric)
importFrom(methods,setMethod)
importFrom(stats,as.dist)
importFrom(stats,optim)
importFrom(utils,combn)
importFrom(utils,modifyList)
